powered by
computegphmm returns GPHMM log probability for a read and a reference sequence.
computegphmm
computegphmm(read, ref, parameters = initializeGphmm(), qv = 20, output = "long")
- chr str.
- list of GPHMM parameters, can be created by initializeGphmm().
- float, quality value, default is 20.
- if 'long', output is a list with path, read, ref and log GPHMM proba, else output is just the log GPHMM proba.
# NOT RUN { computegphmm('TAGC', 'AAG') computegphmm('TAGC', 'AAG', qv = 30) # }
Run the code above in your browser using DataLab